@echo off
REM ***************************************************************************
REM *
REM *  Licensed Materials - Property of IBM and/or HCL
REM *  (c) Copyright IBM Corporation 2005, 2021. All Rights Reserved.
REM *  (c) Copyright HCL Technologies Ltd. 2017, 2021. All Rights Reserved.
REM *
REM *  Note to U.S. Government Users Restricted Rights:
REM *  Use, duplication or disclosure restricted by GSA ADP Schedule
REM *  Contract with IBM Corp.
REM *
REM *
REM *  This batch file compiles the map for the SWIFT JVC validation checking.
REM *  After the map build, the deployment step performs an FTP copy of all of
REM *  the files needed for the system to run.
REM *
REM *  There are 5 parameters needed for this script to execute.
REM *  Any or all of these parameters can be set through command line,
REM *  or can be hard-coded in the set values below.
REM *
REM *  This batch file takes 5 parameters:
REM *  1 = OS Platform: AIX, HPUX, SOLARIS, ZOS, LINUX, ZLINUX, HPITANIUM or WINDOWS
REM *  2 = Operating system user name (if no user name is given, then it is assumed
REM *      the deployment step is not required, and parameters 3 - 5 will not be needed.
REM *  3 = Operating system password
REM *  4 = FTP Server location
REM *  5 = base product target home directory to deploy map files, schemas, and supporting files to the remote system.
REM *      This directory needs to be the root base product location containing the libs directory.
REM *
REM *  NOTE: The script is designed to use paths without spaces for parameter 5.
REM *  Further modification is needed to this script and the ftp template script
REM *   if path names with spaces is to be used.
REM *
REM *  NOTE: For parameter 5, under this top level directory specified, the files
REM *  will be deployed to a sub folder called packs/swift/mt, and distributed to other
REM *  folders underneath this mt folder.
REM *
REM *  EXAMPLE call to the script with all parameters passed:
REM *  build_deploy_jvc.bat AIX username password UNIXMACHINE /usr/apps/base
REM *
REM *  When deploying to a UNIX Platform this script builds an FTP script using
REM *  the script FTP_deploy_jvc_template.scp as a starting template.
REM *
REM *  IF USING THIS TEMPLATE WITH SECURE FTP (SFTP)
REM *  COMMENT OUT THE FIRST THREE LINES IN THE TEMPLATE SCRIPT
REM *  (open command, user, and password)
REM *  ALSO COMMENT OUT THE 'ASCII' and 'BIN' LINES SINCE THESE COMMANDS ARE NOT
REM *  RECOGNIZED IN SFTP
REM *  NOTE LEAVING THESE LINES UNCOMMENTED WILL NOT CAUSE A FAILURE, IT WILL JUST
REM *  REPORT AN UNKNOWN COMMAND WARNING
REM *
REM ***************************************************************************

set dash=-------------------------------------------------------

rem set OS platform - parameter 1
set deploy=true
set PLATFORM=%1
if not defined   PLATFORM    goto :Error_PlatformNotSpecified

rem - set FTP location's OS user account and password. Parameters 2 and 3
set USER=%2
if not defined   USER    goto :no_deploy_params_setup

set PASSWORD=%3
if not defined   PASSWORD    goto :Error_PasswordNotSpecified

rem set FTP server location - Parameter 4
set FTP_SERVER=%4
if not defined   FTP_SERVER    goto :Error_ServerNotSpecified

rem - set target directory for deployment. Parameter 5
set baseDIR=%5
if not defined   baseDIR    goto :Error_PathNotSpecified

if defined USER    goto :skip_no_deploy_params

:no_deploy_params_setup

set deploy=false

:skip_no_deploy_params

rem - define version of the jvalnnn.prop and jvcnnn.jar
set swiftVer=2021

set LOG=build_deploy_jvc.log
rem - clear out old log file...
if exist %LOG% del /f /q %LOG%
rem - create new log file and header for specific base product version...
echo Build and Deploying Pack for SWIFT JVC %swiftVer% on %PLATFORM% > %LOG%
echo FTP Server: %FTP_SERVER% >> %LOG%
echo Using directory: %baseDIR% >> %LOG%
echo %dash% >> %LOG%
echo Start time is: >> %LOG%
time /T >> %LOG%
DATE /T >> %LOG%
echo %dash% >> %LOG%

rem cd to the directory this batch file is running from
rem cd /d %~dp0 - use this if the pushd doesn't work
pushd "%~dp0"
set mapsDir=%CD%
echo MAPSDIR: %mapsDir% >> %LOG%
rem cd to the base product directory to get the location of mcompile.exe
cd ..\..\..\..\..\..\
rem check to make sure mcompile is where we expect it
if exist "%CD%\mcompile.exe" (
    set DTX_HOME=%CD%
) else (
	goto :MCompileNotFound
)

rem set up the directories for all of the files that need to be moved
cd "%mapsDir%"

rem create a directory to hold all of the files that will be deployed

if not exist "%mapsDir%\deployment_jvc" (
	mkdir deployment_jvc
	mkdir deployment_jvc\maps
	mkdir deployment_jvc\metadata
	mkdir deployment_jvc\libs
	)

set DeployDir=%mapsDir%\deployment_jvc

rem cd to the metadata folder and set the SchemaDir
cd ..\metadata
set SchemaDir=%CD%

rem cd to the common folder and set the CommonDir
cd ..\..\..\common
set CommonDir=%CD%

cd %mapsDir%

rem *********************************MAP BUILD**************************************
echo *********************************MAP BUILD************************************** >> %LOG%
echo metadata directory is:      %SchemaDir% >> %LOG%
echo common directory is:      %CommonDir% >> %LOG%
echo deployment directory is:  %DeployDir% >> %LOG%
echo Pack for Financial Payments - SWIFT Component maps directory is: %mapsDir% >> %LOG%
echo base product directory is: %DTX_HOME% >> %LOG%
echo.
echo %dash%
echo === Starting map build...
echo.
set MCOMPILE="%DTX_HOME%\mcompile.exe"
echo mcompile.exe location is: %MCOMPILE% >> %LOG%
set mcompileOptions= -P %PLATFORM% -A -E -O "%DeployDir%\maps\*.mmc"
%MCOMPILE% validate_messages.mms %mcompileOptions% >> %LOG%
echo === Finished validate_messages map build.
echo.
echo === Finished map build.
echo.


rem ********************************COPY FILES**************************************
echo *********************************COPY FILES************************************* >> %LOG%
echo %dash%
echo.
echo === Copying files to deployment directory...

xcopy /r /y  "%CommonDir%\data\*.xml" "%DeployDir%\maps" >> %LOG%

xcopy /r /y  "%mapsDir%\jval%swiftVer%.prop" "%DeployDir%\maps" >> %LOG%
xcopy /r /y  "%SchemaDir%\*.xml" "%DeployDir%\metadata" >> %LOG%
xcopy /r /y  "%DTX_HOME%\jval%swiftVer%.jar" "%DeployDir%\libs" >> %LOG%
xcopy /r /y  "%DTX_HOME%\jvcwrap.jar" "%DeployDir%\libs" >> %LOG%

if %deploy% == false goto :skipDeploy
rem ********************************DEPLOYMENT**************************************
echo *********************************DEPLOYMENT************************************* >> %LOG%
echo.
echo %dash%
echo.
echo === Starting deployment...
echo.

rem ============================================================================
rem :DeployToUnix
rem create the ftp script to run with the user name, password and server
rem to copy all artifacts to remote servers
rem ============================================================================

:DeployToUnix

echo Preparing FTP script to deploy all SWIFT MT JVC artifacts to %PLATFORM% - %FTP_SERVER%...
call :BatchSubstitute "#FTP_SERVER#" %FTP_SERVER% FTP_deploy_jvc_template.scp > start.scp
call :BatchSubstitute "#USER#" %USER% start.scp > user.scp
del start.scp
call :BatchSubstitute "#PASSWORD#" %PASSWORD% user.scp > pw.scp
del user.scp
call :BatchSubstitute "#SERVERHOME#" %baseDIR% pw.scp > basedir.scp
del pw.scp
for %%f in ("%DeployDir%") do set ShortMapDir=%%~sf
call :BatchSubstitute "#DEPLOYDIR#" %ShortMapDir% basedir.scp > deploy.scp
del basedir.scp

echo Created temporary FTP script. >> %LOG%


echo Running FTP script to deploy all SWIFT MT JVC artifacts to %PLATFORM% - %FTP_SERVER%...
echo Running FTP script to deploy all SWIFT MT JVC artifacts to %PLATFORM% - %FTP_SERVER%... >> %LOG%

REM ===========================================================================
REM If using Secure FTP, uncomment out the next line and modify according to
REM your SFTP client command line options.
REM ===========================================================================

rem psftp %USER%@%FTP_SERVER% -pw %PASSWORD% -bc -be -b deploy.scp >> %LOG%

ftp -s:deploy.scp  >> %LOG%

REM ===========================================================================
REM for troubleshooting FTP issues, comment out the next line and
REM analyze the file deploy.scp
REM ===========================================================================
del deploy.scp

goto :Run_EXIT

rem ============================================================================
rem :BatchSubstitute
rem  Text string find/replace.
rem ============================================================================

:BatchSubstitute

REM -- Prepare the Command Processor --
setLOCAL ENABLEEXTENSIONS
setLOCAL DISABLEDELAYEDEXPANSION

if "%*"=="" findstr "^::" "%~f0"&GOTO:EOF
for /f "tokens=1,* delims=]" %%A in ('"type %3|find /n /v """') do (
    set "line=%%B"
    if defined line (
        call set "line=echo.%%line:%~1=%~2%%"
        for /f "delims=" %%X in ('"echo."%%line%%""') do %%~X
    ) ELSE echo.
)

goto :EOF

:Error_UserNotSpecified
set ERROR=No OS User specified.
goto :Print_Error

:Error_PasswordNotSpecified
set ERROR=No OS Password specified.
goto :Print_Error

:Error_PlatformNotSpecified
set ERROR=No OS Platform specified.
goto :Print_Error

:Error_ServerNotSpecified
set ERROR=No FTP Server location specified.
goto :Print_Error

:Error_PathNotSpecified
set ERROR=No top level directory specified.
goto :Print_Error

:Print_Error
echo.
echo %dash%
echo Error: %ERROR%
echo %dash%
goto :Print_Params

:Print_Params
echo.
echo This batch file takes 5 parameters:
echo.
echo 1 = OS Platform: AIX, HPUX, SOLARIS, ZOS, LINUX, ZLINUX, HPITANIUM or WINDOWS
echo.
echo 2 = Operating system user name
echo.
echo 3 = Operating system password
echo.
echo 4 = FTP Server location
echo.
echo 5 = top level directory to deploy map files, schemas, and supporting files to the remote system.
echo     This directory needs to be the root of base product location containing the libs directory.
echo.
echo EXAMPLE: build_deploy_jvc.bat AIX username password  UNIXMACHINE /usr/bin/base/packs/swift
goto :EOF

:MCompileNotFound
echo %dash%
echo.
echo base product directory not found!
echo This script must run from the SWIFT component default installation subdirectory: mt\jvc\maps.
echo Example: "<base product install dir>\packs\financial_payments_v<version>\swift\mt\jvc\maps"
echo.
echo %dash%
goto :EOF

:skipDeploy
echo Skipping FTP deployment of all SWIFT MT JVC artifacts...
echo Skipping FTP deployment of all SWIFT MT JVC artifacts... >> %LOG%

:Run_EXIT

echo %dash%
echo === Map compile and deploy script completed
echo.
echo === The log of actions titled build_deploy_jvc.log is located at %CD%
echo %dash%
goto :EOF
